function [unew] = eqdiff1(N = 9, M = 100, h = 5E-3)
%
%  Schema d'Euler progressif pour un systeme differentiel
%
%  parametres
%
%  N        : nombre d'inconnues du systeme differentiel
%  M        : nombre de pas de temps
%  h        : pas de temps
%  uold     : N-vecteur, approximation de la solution du systeme differentiel
%             au temps t_n
%  unew     : N-vecteur, approximation de la solution du systeme differentiel
%             au temps t_{n+1}
%
alpha = (N + 1)^2;

%
% condition initiale
%
for i = 1 : N
  uold(i) = 1.;
end
%
% schema d'Euler progressif : u^{n+1} = (I-hA) u^{n}
%
for n = 1 : M
  unew(1) = ?;
  for i = 2 : N - 1
    unew(i) = ?;
  end
  unew(N) = ?;  

%
% reactualisation de la solution
% et impression de la norme euclidienne de u^{n+1}
%
  norm2 = 0;
  for i = 1 : N
    uold(i) = unew(i);
    norm2 = norm2 + unew(i) * unew(i);
  end
  norm2
  
end
end

